﻿using Microsoft.Extensions.Logging;
using PizzeriaContracts.BindingModels;
using SushiBarContracts.BusinessLogicsContracts;
using SushiBarContracts.ViewModels;


namespace PizzeriaView
{
    public partial class FormCreateSupply : Form
    {
        private readonly ILogger _logger;
        private readonly ISushiLogic _logicS;
        private readonly IShopLogic _logicSh;
        private List<ShopViewModel> _ShopList = new List<ShopViewModel>();
        private List<SushiViewModel> _SushiList = new List<SushiViewModel>();

        public FormCreateSupply(ILogger<FormCreateSupply> logger, ISushiLogic logicS, IShopLogic logicSh)
        {
            InitializeComponent();
            _logger = logger;
            _logicS = logicS;
            _logicSh = logicSh;
        }

        private void FormCreateSupply_Load(object sender, EventArgs e)
        {
            _ShopList = _logicSh.ReadList(null);
            _SushiList = _logicS.ReadList(null);
            if (_ShopList != null)
            {
                comboBoxShop.DisplayMember = "ShopName";
                comboBoxShop.ValueMember = "Id";
                comboBoxShop.DataSource = _ShopList;
                comboBoxShop.SelectedItem = null;
                _logger.LogInformation("Загрузка магазинов для поставок");
            }
            if (_SushiList != null)
            {
                comboBoxSushi.DisplayMember = "SushiName";
                comboBoxSushi.ValueMember = "Id";
                comboBoxSushi.DataSource = _SushiList;
                comboBoxSushi.SelectedItem = null;
                _logger.LogInformation("Загрузка  суши для поставок");
            }
        }

        private void ButtonSave_Click(object sender, EventArgs e)
        {
            if (comboBoxShop.SelectedValue == null)
            {
                MessageBox.Show("Выберите магазин", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (comboBoxSushi.SelectedValue == null)
            {
                MessageBox.Show("Выберите изделие", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            _logger.LogInformation("Создание поставки");
            try
            {
                var operationResult = _logicSh.MakeSupply(new SupplyBindingModel
                {
                    ShopId = Convert.ToInt32(comboBoxShop.SelectedValue),
                    SushiId = Convert.ToInt32(comboBoxSushi.SelectedValue),
                    Count = Convert.ToInt32(textBoxCount.Text)
                });
                if (!operationResult)
                {
                    throw new Exception("Ошибка при создании поставки. Дополнительная информация в логах.");
                }
                MessageBox.Show("Сохранение прошло успешно", "Сообщение", MessageBoxButtons.OK, MessageBoxIcon.Information);
                DialogResult = DialogResult.OK;
                Close();
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка создания поставки");
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonCancel_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
            Close();
        }
    }
}
